# NAME

remctl-acl-update-flex - Update remctl ACLs on local disk

# SYNOPSIS

**remctl-acl-update-flex** \[--dry-run\] \[--source=afs|https\] \[--dest-dir=&lt;path>\] \[_acl_ ...\]

**remctl-acl-update-flex** \[-h|--help\]

**remctl-acl-update-flex** \[-m|--manual\]

# DESCRIPTION

The default action is, for the list of ACLs specified at the beginning of
this shell script, check to see if the source version  is newer than the
version on local disk.  If so, copy the version from source to local disk,
preserving timestamps.

The source is either AFS (the default) or the HTTPS remctl ACL file
service (used when **--source** is set to "https").

This script only adds/updates files; no remctl files are _removed_.

If ACLs are given on the command line, those files are copied instead of the
default set.  This allows adding an additional cron job to copy other ACLs
that a given server cares about without copying the same ACLs twice.

As a special case, this script also creates `its-idg`, `its-systems`,
and `systems-root` ACL files, generated by extracting only root instances
from the corresponding ACL files without the `-root` ending.

If there are admin instances in `/root/.k5login`, or if `/root/.k5login`
doesn't exist, this script removes the `operations` and `systems` ACLs
from the default set.  This is to prevent changing ACL files on systems
with more restricted access than normal.  It also declines to update the
`operations` and `systems` ACLs if the `systems` ACL contains lines of
the form `file:_path_`, since it then assumes that those ACLs are
pointed at the appropriate group-specific ACLs instead of using the
general ACL.

# OPTIONS

- **--source**=afs|https

    Use the **--source** option to specify which source you want to use for the
    ACL file downloads: AFS or the HTTPS service. Both sources have the same
    files. The default is `afs`. Supplying any other value than "afs" or
    "https" will result in an error.

- **--dest-dir**=&lt;path>

    Normally this script will write the remctl ACL files to the directory
    **/etc/remctl/acl**. To override this use the **--dest-dir** option. For
    example, to write the remctl ACL files to `/tmp/acl` use
    "**--dest-dir**=`/tmp/acl`".  Note that if the destination directory does
    not already exist the script will exit with an error.

- **--dry-run|-n**

    Run in "dry-run" mode. This mode downloads the file to a temporary
    directory (just like normal mode) but does **not** write them to the
    destination directory. Use with the **--verbose** option when debugging.

- **--platform**=dev|prod

    Normally this program will download the remctl ACL files from the
    production remctl ACL file storage bucket. Howevever, if you want to
    download them from the _non-production_ bucket, use this option like so:
    **--platform=dev**. This option only recognizes two values: "prod" or "dev".
    See also the Examples below.

- **--baseurl**=&lt;url>

    The script normally infers the remctl ACL file service URL from the
    **--platform** option, but you can override this and specify the URL
    yourself by using the **--baseurl** option.

- **--verbose|-v**

    Run in verbose mode.

- **--help|-h**

    Show a help summary and exit.

- **--manual|-m**

    Show the man page and exit. Will only work if pod2man is installed.

# EXAMPLES

To update the default set of ACLs (using AFS as the source), just run:

    remctl-acl-update-flex

To update the default set of ACLs (using HTTPS as the source), run:

    remctl-acl-update-flex --source=https

To update a specific ACL (whether one of the defaults or not), do:

    remctl-acl-update-flex helpdesk-all

This will copy the helpdesk-all ACL file into `/etc/remctl/acl`.

To download from the non-production storage bucket:

    remctl-acl-update-flex --platform=dev

# FILES

- `/afs/ir.stanford.edu/pubsw/Local/config/share/etc/acl`

    The directory in pubsw that is checked for newer copies of the ACLs. If
    this directory doesn't exist, the script exits quietly without changing
    anything. The ACLs in this directory are expected to end in `.acl` but
    are copied over without that extension. Note that this directory is
    \*not\* used when the **--source** option is set to "https".

- `/etc/remctl/acl`

    The local directory where the ACL files are stored (unless overridden by
    the **--dest-dir** option).

# AUTHOR

Russ Allbery <rra@stanford.edu>

Updated by Adam H. Lewenberg <adamhl@stanford.edu>
